@@ -9,11 +9,11 @@ from time import perf_counter, sleep
 from requests import Session
 
 from .base import BasePage
-from .chromium_element import ChromiumElementWaiter, ChromeScroll, ChromiumElement, run_script, make_chromium_ele
+from .chromium_element import ChromiumElementWaiter, ChromiumScroll, ChromiumElement, run_js, make_chromium_ele
 from .common import get_loc
 from .config import cookies_to_tuple
 from .session_element import make_session_ele
-from .tab import Tab
+from .chromium_driver import ChromiumDriver
 
 
 class ChromiumBase(BasePage):
@@ -33,9 +33,9 @@ class ChromiumBase(BasePage):
         self.timeouts = Timeout(self)
         self._connect_browser(address, tab_id)
 
-    def _connect_browser(self, addr_tab_opts=None, tab_id=None):
+    def _connect_browser(self, addr_driver_opts=None, tab_id=None):
         """连接浏览器，在第一次时运行                                    \n
-        :param addr_tab_opts: 浏览器地址、Tab对象或DriverOptions对象
+        :param addr_driver_opts: 浏览器地址、ChromiumDriver对象或DriverOptions对象
         :param tab_id: 要控制的标签页id，不指定默认为激活的
         :return: None
         """
@@ -45,7 +45,7 @@ class ChromiumBase(BasePage):
         self._first_run = True
         self._is_reading = False  # 用于避免不同线程重复读取document
 
-        self.address = addr_tab_opts
+        self.address = addr_driver_opts
         if not tab_id:
             json = self._control_session.get(f'http://{self.address}/json').json()
             tab_id = [i['id'] for i in json if i['type'] == 'page'][0]
@@ -61,8 +61,8 @@ class ChromiumBase(BasePage):
         """
         self._is_loading = True
         if tab_id:
-            self._tab_obj = Tab(id=tab_id, type='page',
-                                webSocketDebuggerUrl=f'ws://{self.address}/devtools/page/{tab_id}')
+            self._tab_obj = ChromiumDriver(id=tab_id, type='page',
+                                           webSocketDebuggerUrl=f'ws://{self.address}/devtools/page/{tab_id}')
 
         self._tab_obj.start()
         self._tab_obj.DOM.enable()
@@ -195,16 +195,17 @@ class ChromiumBase(BasePage):
 
     @property
     def driver(self):
-        """返回用于控制浏览器的Tab对象"""
+        """返回用于控制浏览器的ChromiumDriver对象"""
         return self._tab_obj
 
     @property
     def _driver(self):
+        """返回用于控制浏览器的ChromiumDriver对象"""
         return self._tab_obj
 
     @property
     def _wait_driver(self):
-        """返回用于控制浏览器的Tab对象，会先等待页面加载完毕"""
+        """返回用于控制浏览器的ChromiumDriver对象，会先等待页面加载完毕"""
         while self._is_loading:
             sleep(.1)
         return self._tab_obj
@@ -226,8 +227,11 @@ class ChromiumBase(BasePage):
 
     @property
     def json(self):
-        """当返回内容是json格式时，返回对应的字典"""
-        return loads(self('t:pre').text)
+        """当返回内容是json格式时，返回对应的字典，非json格式时返回None"""
+        try:
+            return loads(self('t:pre', timeout=.5).text)
+        except Exception:
+            return None
 
     @property
     def tab_id(self):
@@ -242,25 +246,25 @@ class ChromiumBase(BasePage):
     @property
     def size(self):
         """返回页面总长高，格式：(长, 高)"""
-        w = self.run_script('document.body.scrollWidth;', as_expr=True)
-        h = self.run_script('document.body.scrollHeight;', as_expr=True)
+        w = self.run_js('document.body.scrollWidth;', as_expr=True)
+        h = self.run_js('document.body.scrollHeight;', as_expr=True)
         return w, h
 
     @property
     def active_ele(self):
         """返回当前焦点所在元素"""
-        return self.run_script('return document.activeElement;')
+        return self.run_js('return document.activeElement;')
 
     @property
     def page_load_strategy(self):
-        """返回页面加载策略"""
+        """返回页面加载策略，有3种：'none'、'normal'、'eager'"""
         return self._page_load_strategy
 
     @property
     def scroll(self):
         """返回用于滚动滚动条的对象"""
         if not hasattr(self, '_scroll'):
-            self._scroll = ChromeScroll(self)
+            self._scroll = ChromiumScroll(self)
         return self._scroll
 
     @property
@@ -284,24 +288,24 @@ class ChromiumBase(BasePage):
         if script is not None:
             self.timeouts.script = script
 
-    def run_script(self, script, as_expr=False, *args):
+    def run_js(self, script, as_expr=False, *args):
         """运行javascript代码                                                 \n
         :param script: js文本
         :param as_expr: 是否作为表达式运行，为True时args无效
-        :param args: 参数，按顺序在js文本中对应argument[0]、argument[2]...
+        :param args: 参数，按顺序在js文本中对应argument[0]、argument[1]...
         :return: 运行的结果
         """
-        return run_script(self, script, as_expr, self.timeouts.script, args)
+        return run_js(self, script, as_expr, self.timeouts.script, args)
 
-    def run_async_script(self, script, as_expr=False, *args):
+    def run_async_js(self, script, as_expr=False, *args):
         """以异步方式执行js代码                                                 \n
         :param script: js文本
         :param as_expr: 是否作为表达式运行，为True时args无效
-        :param args: 参数，按顺序在js文本中对应argument[0]、argument[2]...
+        :param args: 参数，按顺序在js文本中对应argument[0]、argument[1]...
         :return: None
         """
         from threading import Thread
-        Thread(target=run_script, args=(self, script, as_expr, self.timeouts.script, args)).start()
+        Thread(target=run_js, args=(self, script, as_expr, self.timeouts.script, args)).start()
 
     def get(self, url, show_errmsg=False, retry=None, interval=None, timeout=None):
         """访问url                                            \n
@@ -325,12 +329,14 @@ class ChromiumBase(BasePage):
         :param timeout: 超时时间
         :return: 等待结束时是否进入加载状态
         """
-        end_time = perf_counter() + timeout
-        while perf_counter() < end_time:
-            if self.is_loading:
-                return True
-            sleep(.005)
-        return False
+        if timeout:
+            timeout = 2 if timeout is True else timeout
+            end_time = perf_counter() + timeout
+            while perf_counter() < end_time:
+                if self.is_loading:
+                    return True
+                sleep(.005)
+            return False
 
     def get_cookies(self, as_dict=False):
         """获取cookies信息                                              \n
@@ -359,12 +365,12 @@ class ChromiumBase(BasePage):
             result_cookies.append(c)
         self._wait_driver.Network.setCookies(cookies=result_cookies)
 
-    # def set_headers(self, headers: dict) -> None:
-    #     """设置固定发送的headers                        \n
-    #     :param headers: dict格式的headers数据
-    #     :return: None
-    #     """
-    #     self.run_cdp('Network.setExtraHTTPHeaders', headers=headers)
+    def set_headers(self, headers: dict) -> None:
+        """设置固定发送的headers                        \n
+        :param headers: dict格式的headers数据
+        :return: None
+        """
+        self.run_cdp('Network.setExtraHTTPHeaders', headers=headers, not_change=True)
 
     def ele(self, loc_or_ele, timeout=None):
         """获取第一个符合条件的元素对象                       \n
@@ -457,7 +463,7 @@ class ChromiumBase(BasePage):
         try:
             self._wait_driver.DOM.scrollIntoViewIfNeeded(nodeId=node_id)
         except Exception:
-            self.ele(loc_or_ele).run_script("this.scrollIntoView();")
+            self.ele(loc_or_ele).run_js("this.scrollIntoView();")
 
     def refresh(self, ignore_cache=False):
         """刷新当前页面                      \n
@@ -550,7 +556,7 @@ class ChromiumBase(BasePage):
         :return: sessionStorage一个或所有项内容
         """
         js = f'sessionStorage.getItem("{item}");' if item else 'sessionStorage;'
-        return self.run_script(js, as_expr=True)
+        return self.run_js(js, as_expr=True)
 
     def get_local_storage(self, item=None):
         """获取localStorage信息，不设置item则获取全部       \n
@@ -558,7 +564,7 @@ class ChromiumBase(BasePage):
         :return: localStorage一个或所有项内容
         """
         js = f'localStorage.getItem("{item}");' if item else 'localStorage;'
-        return self.run_script(js, as_expr=True)
+        return self.run_js(js, as_expr=True)
 
     def set_session_storage(self, item, value):
         """设置或删除某项sessionStorage信息                         \n
@@ -567,7 +573,7 @@ class ChromiumBase(BasePage):
         :return: None
         """
         js = f'sessionStorage.removeItem("{item}");' if item is False else f'sessionStorage.setItem("{item}","{value}");'
-        return self.run_script(js, as_expr=True)
+        return self.run_js(js, as_expr=True)
 
     def set_local_storage(self, item, value):
         """设置或删除某项localStorage信息                           \n
@@ -576,7 +582,7 @@ class ChromiumBase(BasePage):
         :return: None
         """
         js = f'localStorage.removeItem("{item}");' if item is False else f'localStorage.setItem("{item}","{value}");'
-        return self.run_script(js, as_expr=True)
+        return self.run_js(js, as_expr=True)
 
     def clear_cache(self, session_storage=True, local_storage=True, cache=True, cookies=True):
         """清除缓存，可选要清除的项                            \n
@@ -587,9 +593,9 @@ class ChromiumBase(BasePage):
         :return: None
         """
         if session_storage:
-            self.run_script('sessionStorage.clear();', as_expr=True)
+            self.run_js('sessionStorage.clear();', as_expr=True)
         if local_storage:
-            self.run_script('localStorage.clear();', as_expr=True)
+            self.run_js('localStorage.clear();', as_expr=True)
         if cache:
             self._wait_driver.Network.clearBrowserCache()
         if cookies:
@@ -660,7 +666,7 @@ class PageLoadStrategy(object):
         """
         :param page: ChromiumBase对象
         """
-        self.page = page
+        self._page = page
 
     def __call__(self, value):
         """设置加载策略                                  \n
@@ -669,16 +675,16 @@ class PageLoadStrategy(object):
         """
         if value.lower() not in ('normal', 'eager', 'none'):
             raise ValueError("只能选择 'normal', 'eager', 'none'。")
-        self.page._page_load_strategy = value
+        self._page._page_load_strategy = value
 
     def normal(self):
         """设置页面加载策略为normal"""
-        self.page._page_load_strategy = 'normal'
+        self._page._page_load_strategy = 'normal'
 
     def eager(self):
         """设置页面加载策略为eager"""
-        self.page._page_load_strategy = 'eager'
+        self._page._page_load_strategy = 'eager'
 
     def none(self):
         """设置页面加载策略为none"""
-        self.page._page_load_strategy = 'none'
+        self._page._page_load_strategy = 'none'
