@@ -14,23 +14,23 @@ from .chromium_base import Timeout, ChromiumBase
 from .chromium_tab import ChromiumTab
 from .common import connect_chrome
 from .config import DriverOptions
-from .tab import Tab
+from .chromium_driver import ChromiumDriver
 
 
 class ChromiumPage(ChromiumBase):
     """用于管理浏览器的类"""
 
-    def __init__(self, addr_tab_opts=None, tab_id=None, timeout=None):
-        """初始化                                                      \n
-        :param addr_tab_opts: 浏览器地址:端口、Tab对象或DriverOptions对象
+    def __init__(self, addr_driver_opts=None, tab_id=None, timeout=None):
+        """初始化                                                                       \n
+        :param addr_driver_opts: 浏览器地址:端口、ChromiumDriver对象或DriverOptions对象
         :param tab_id: 要控制的标签页id，不指定默认为激活的
         :param timeout: 超时时间
         """
-        super().__init__(addr_tab_opts, tab_id, timeout)
+        super().__init__(addr_driver_opts, tab_id, timeout)
 
-    def _connect_browser(self, addr_tab_opts=None, tab_id=None):
+    def _connect_browser(self, addr_driver_opts=None, tab_id=None):
         """连接浏览器，在第一次时运行                                    \n
-        :param addr_tab_opts: 浏览器地址、Tab对象或DriverOptions对象
+        :param addr_driver_opts: 浏览器地址、ChromiumDriver对象或DriverOptions对象
         :param tab_id: 要控制的标签页id，不指定默认为激活的
         :return: None
         """
@@ -44,38 +44,38 @@ class ChromiumPage(ChromiumBase):
         self._first_run = True
 
         # 接管或启动浏览器
-        if addr_tab_opts is None or isinstance(addr_tab_opts, DriverOptions):
-            self.options = addr_tab_opts or DriverOptions()  # 从ini文件读取
+        if addr_driver_opts is None or isinstance(addr_driver_opts, DriverOptions):
+            self.options = addr_driver_opts or DriverOptions()  # 从ini文件读取
             self.address = self.options.debugger_address
             self.process = connect_chrome(self.options)[1]
             json = self._control_session.get(f'http://{self.address}/json').json()
             tab_id = [i['id'] for i in json if i['type'] == 'page'][0]
 
         # 接收浏览器地址和端口
-        elif isinstance(addr_tab_opts, str):
-            self.address = addr_tab_opts
+        elif isinstance(addr_driver_opts, str):
+            self.address = addr_driver_opts
             self.options = DriverOptions(read_file=False)
-            self.options.debugger_address = addr_tab_opts
+            self.options.debugger_address = addr_driver_opts
             self.process = connect_chrome(self.options)[1]
             if not tab_id:
                 json = self._control_session.get(f'http://{self.address}/json').json()
                 tab_id = [i['id'] for i in json if i['type'] == 'page'][0]
 
-        # 接收传递过来的Tab，浏览器
-        elif isinstance(addr_tab_opts, Tab):
-            self._tab_obj = addr_tab_opts
-            self.address = search(r'ws://(.*?)/dev', addr_tab_opts._websocket_url).group(1)
+        # 接收传递过来的ChromiumDriver，浏览器
+        elif isinstance(addr_driver_opts, ChromiumDriver):
+            self._tab_obj = addr_driver_opts
+            self.address = search(r'ws://(.*?)/dev', addr_driver_opts._websocket_url).group(1)
             self.process = None
             self.options = DriverOptions(read_file=False)
 
         else:
-            raise TypeError('只能接收Tab或DriverOptions类型参数。')
+            raise TypeError('只能接收ChromiumDriver或DriverOptions类型参数。')
 
         self._set_options()
         self._init_page(tab_id)
         self._get_document()
         self._first_run = False
-        self.main_tab: str = self.tab_id
+        self._main_tab = self.tab_id
 
     def _init_page(self, tab_id=None):
         """新建页面、页面刷新、切换标签页后要进行的cdp参数初始化
@@ -100,10 +100,14 @@ class ChromiumPage(ChromiumBase):
 
     @property
     def tabs(self):
-        """返回所有标签页id"""
+        """返回所有标签页id组成的列表"""
         tabs = self.run_cdp('Target.getTargets', filter=[{'type': "page"}])['targetInfos']
         return [i['targetId'] for i in tabs]
 
+    @property
+    def main_tab(self):
+        return self._main_tab
+
     @property
     def process_id(self):
         """返回浏览器进程id"""
@@ -116,7 +120,7 @@ class ChromiumPage(ChromiumBase):
     def set_window(self):
         """返回用于设置窗口大小的对象"""
         if not hasattr(self, '_window_setter'):
-            self._window_setter = WindowSizeSetter(self)
+            self._window_setter = WindowSetter(self)
         return self._window_setter
 
     def get_tab(self, tab_id=None):
@@ -129,8 +133,8 @@ class ChromiumPage(ChromiumBase):
 
     def get_screenshot(self, path=None, as_bytes=None, full_page=False, left_top=None, right_bottom=None):
         """对页面进行截图，可对整个网页、可见网页、指定范围截图。对可视范围外截图需要90以上版本浏览器支持             \n
-        :param path: 完整路径，后缀可选'jpg','jpeg','png','webp'
-        :param as_bytes: 是否已字节形式返回图片，可选'jpg','jpeg','png','webp'，生效时path参数无效
+        :param path: 完整路径，后缀可选 'jpg','jpeg','png','webp'
+        :param as_bytes: 是否已字节形式返回图片，可选 'jpg','jpeg','png','webp'，生效时path参数无效
         :param full_page: 是否整页截图，为True截取整个网页，为False截取可视窗口
         :param left_top: 截取范围左上角坐标
         :param right_bottom: 截取范围右下角角坐标
@@ -184,7 +188,7 @@ class ChromiumPage(ChromiumBase):
         self._control_session.get(f'http://{self.address}/json/activate/{self.tab_id}')
 
     def new_tab(self, url=None, switch_to=True):
-        """新建并定位到一个标签页,该标签页在最后面         \n
+        """新建一个标签页,该标签页在最后面                \n
         :param url: 新标签页跳转到的网址
         :param switch_to: 新建标签页后是否把焦点移过去
         :return: None
@@ -207,9 +211,16 @@ class ChromiumPage(ChromiumBase):
         else:
             self._control_session.get(f'http://{self.address}/json/new')
 
+    def set_main_tab(self, tab_id=None):
+        """设置主tab                               \n
+        :param tab_id: 标签页id，不传入则设置当前tab
+        :return: None
+        """
+        self._main_tab = tab_id or self.tab_id
+
     def to_main_tab(self):
         """跳转到主标签页"""
-        self.to_tab(self.main_tab)
+        self.to_tab(self._main_tab)
 
     def to_tab(self, tab_id=None, activate=True):
         """跳转到标签页                                           \n
@@ -228,7 +239,7 @@ class ChromiumPage(ChromiumBase):
         """
         tabs = self.tabs
         if not tab_id:
-            tab_id = self.main_tab
+            tab_id = self._main_tab
         if tab_id not in tabs:
             tab_id = tabs[0]
 
@@ -273,8 +284,8 @@ class ChromiumPage(ChromiumBase):
         while len(self.tabs) != end_len:
             sleep(.1)
 
-        if self.main_tab in tabs:
-            self.main_tab = self.tabs[0]
+        if self._main_tab in tabs:
+            self._main_tab = self.tabs[0]
 
         self.to_tab()
 
@@ -350,7 +361,7 @@ class Alert(object):
         self.response_text = None
 
 
-class WindowSizeSetter(object):
+class WindowSetter(object):
     """用于设置窗口大小的类"""
 
     def __init__(self, page):
@@ -373,7 +384,7 @@ class WindowSizeSetter(object):
         """设置窗口为常规模式"""
         self._perform({'windowState': 'normal'})
 
-    def new_size(self, width=None, height=None):
+    def size(self, width=None, height=None):
         """设置窗口大小             \n
         :param width: 窗口宽度
         :param height: 窗口高度
@@ -385,7 +396,7 @@ class WindowSizeSetter(object):
             height = height or info['height']
             self._perform({'width': width, 'height': height})
 
-    def to_location(self, x=None, y=None):
+    def location(self, x=None, y=None):
         """设置窗口在屏幕中的位置，相对左上角坐标  \n
         :param x: 距离顶部距离
         :param y: 距离左边距离
