@@ -2,38 +2,33 @@
 """
 @Author  :   g1879
 @Contact :   g1879@qq.com
-@File    :   driver_page.py
 """
 from glob import glob
 from os import sep
 from pathlib import Path
 from time import sleep, perf_counter
-from typing import Union, List, Any, Tuple
 
 from selenium.common.exceptions import NoAlertPresentException
-from selenium.webdriver.chrome.webdriver import WebDriver
-from selenium.webdriver.remote.webdriver import WebDriver as RemoteWebDriver
 from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.support.wait import WebDriverWait
 
 from .base import BasePage
 from .common import get_usable_path
 from .driver_element import DriverElement, make_driver_ele, Scroll, ElementWaiter
-from .session_element import make_session_ele, SessionElement
+from .session_element import make_session_ele
 
 
 class DriverPage(BasePage):
     """DriverPage封装了页面操作的常用功能，使用selenium来获取、解析、操作网页"""
 
-    def __init__(self, driver: RemoteWebDriver, timeout: float = 10) -> None:
+    def __init__(self, driver, timeout=10):
         """初始化函数，接收一个WebDriver对象，用来操作网页"""
         super().__init__(timeout)
         self._driver = driver
         self._wait_object = None
         self._scroll = None
 
-    def __call__(self, loc_or_str: Union[Tuple[str, str], str, DriverElement, WebElement],
-                 timeout: float = None) -> Union[DriverElement, str, None]:
+    def __call__(self, loc_or_str, timeout=None):
         """在内部查找元素                                           \n
         例：ele = page('@id=ele_id')                              \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
@@ -44,7 +39,7 @@ class DriverPage(BasePage):
 
     # -----------------共有属性和方法-------------------
     @property
-    def url(self) -> Union[str, None]:
+    def url(self):
         """返回当前网页url"""
         if not self._driver or not self.driver.current_url.startswith('http'):
             return None
@@ -52,21 +47,17 @@ class DriverPage(BasePage):
             return self.driver.current_url
 
     @property
-    def html(self) -> str:
+    def html(self):
         """返回页面的html文本"""
         return self.driver.find_element('xpath', "//*").get_attribute("outerHTML")
 
     @property
-    def json(self) -> dict:
+    def json(self):
         """当返回内容是json格式时，返回对应的字典"""
         from json import loads
         return loads(self('t:pre').text)
 
-    def get(self,
-            url: str,
-            show_errmsg: bool = False,
-            retry: int = None,
-            interval: float = None) -> Union[None, bool]:
+    def get(self, url, show_errmsg=False, retry=None, interval=None):
         """访问url                                            \n
         :param url: 目标url
         :param show_errmsg: 是否显示和抛出异常
@@ -84,9 +75,7 @@ class DriverPage(BasePage):
 
         return self._url_available
 
-    def ele(self,
-            loc_or_ele: Union[Tuple[str, str], str, DriverElement, WebElement],
-            timeout: float = None) -> Union[DriverElement, str, None]:
+    def ele(self, loc_or_ele, timeout=None):
         """返回页面中符合条件的第一个元素                                          \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与页面等待时间一致
@@ -94,9 +83,7 @@ class DriverPage(BasePage):
         """
         return self._ele(loc_or_ele, timeout)
 
-    def eles(self,
-             loc_or_str: Union[Tuple[str, str], str],
-             timeout: float = None) -> List[Union[DriverElement, str]]:
+    def eles(self, loc_or_str, timeout=None):
         """返回页面中所有符合条件的元素                                     \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与页面等待时间一致
@@ -104,7 +91,7 @@ class DriverPage(BasePage):
         """
         return self._ele(loc_or_str, timeout, single=False)
 
-    def s_ele(self, loc_or_ele: Union[Tuple[str, str], str, DriverElement] = None) -> Union[SessionElement, str, None]:
+    def s_ele(self, loc_or_ele=None):
         """查找第一个符合条件的元素以SessionElement形式返回，处理复杂页面时效率很高       \n
         :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
@@ -114,17 +101,14 @@ class DriverPage(BasePage):
         else:
             return make_session_ele(self, loc_or_ele)
 
-    def s_eles(self, loc_or_str: Union[Tuple[str, str], str] = None) -> List[Union[SessionElement, str]]:
+    def s_eles(self, loc_or_str=None):
         """查找所有符合条件的元素以SessionElement列表形式返回                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象组成的列表
         """
         return make_session_ele(self, loc_or_str, single=False)
 
-    def _ele(self,
-             loc_or_ele: Union[Tuple[str, str], str, DriverElement, WebElement],
-             timeout: float = None,
-             single: bool = True) -> Union[DriverElement, str, None, List[Union[DriverElement, str]]]:
+    def _ele(self, loc_or_ele, timeout=None, single=True):
         """返回页面中符合条件的元素，默认返回第一个                                   \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 查找元素超时时间
@@ -147,7 +131,7 @@ class DriverPage(BasePage):
         else:
             raise ValueError('loc_or_str参数只能是tuple、str、DriverElement 或 WebElement类型。')
 
-    def get_cookies(self, as_dict: bool = False) -> Union[list, dict]:
+    def get_cookies(self, as_dict=False):
         """返回当前网站cookies"""
         if as_dict:
             return {cookie['name']: cookie['value'] for cookie in self.driver.get_cookies()}
@@ -155,21 +139,17 @@ class DriverPage(BasePage):
             return self.driver.get_cookies()
 
     @property
-    def timeout(self) -> float:
+    def timeout(self):
         """返回查找元素时等待的秒数"""
         return self._timeout
 
     @timeout.setter
-    def timeout(self, second: float) -> None:
+    def timeout(self, second):
         """设置查找元素时等待的秒数"""
         self._timeout = second
         self._wait_object = None
 
-    def _d_connect(self,
-                   to_url: str,
-                   times: int = 0,
-                   interval: float = 1,
-                   show_errmsg: bool = False) -> Union[bool, None]:
+    def _d_connect(self, to_url, times=0, interval=1, show_errmsg=False):
         """尝试连接，重试若干次                            \n
         :param to_url: 要访问的url
         :param times: 重试次数
@@ -205,11 +185,11 @@ class DriverPage(BasePage):
 
     # ----------------driver独有属性和方法-----------------------
     @property
-    def driver(self) -> WebDriver:
+    def driver(self):
         return self._driver
 
     @property
-    def wait_object(self) -> WebDriverWait:
+    def wait_object(self):
         """返回WebDriverWait对象，重用避免每次新建对象"""
         if self._wait_object is None:
             self._wait_object = WebDriverWait(self.driver, timeout=self.timeout)
@@ -217,14 +197,14 @@ class DriverPage(BasePage):
         return self._wait_object
 
     @property
-    def timeouts(self) -> dict:
+    def timeouts(self):
         """返回三种超时时间，selenium4以上版本可用"""
         return {'implicit': self.timeout,
                 'pageLoad': self.driver.timeouts.page_load,
                 'script': self.driver.timeouts.script}
 
     @property
-    def tabs_count(self) -> int:
+    def tabs_count(self):
         """返回标签页数量"""
         try:
             return len(self.driver.window_handles)
@@ -232,34 +212,34 @@ class DriverPage(BasePage):
             return 0
 
     @property
-    def tab_handles(self) -> list:
+    def tab_handles(self):
         """返回所有标签页handle列表"""
         return self.driver.window_handles
 
     @property
-    def current_tab_index(self) -> int:
+    def current_tab_index(self):
         """返回当前标签页序号"""
         return self.driver.window_handles.index(self.driver.current_window_handle)
 
     @property
-    def current_tab_handle(self) -> str:
+    def current_tab_handle(self):
         """返回当前标签页handle"""
         return self.driver.current_window_handle
 
     @property
-    def active_ele(self) -> DriverElement:
+    def active_ele(self):
         """返回当前焦点所在元素"""
         return DriverElement(self.driver.switch_to.active_element, self)
 
     @property
-    def scroll(self) -> Scroll:
+    def scroll(self):
         """用于滚动滚动条的对象"""
         if self._scroll is None:
             self._scroll = Scroll(self)
         return self._scroll
 
     @property
-    def to_frame(self) -> 'ToFrame':
+    def to_frame(self):
         """用于跳转到frame的对象，调用其方法实现跳转                                             \n
         示例：                                                                               \n
             page.to_frame.by_loc('tag:iframe')               - 通过传入frame的查询字符串定位   \n
@@ -273,7 +253,7 @@ class DriverPage(BasePage):
         """
         return ToFrame(self)
 
-    def set_timeouts(self, implicit: float = None, pageLoad: float = None, script: float = None) -> None:
+    def set_timeouts(self, implicit=None, pageLoad=None, script=None):
         """设置超时时间，单位为秒，selenium4以上版本有效       \n
         :param implicit: 查找元素超时时间
         :param pageLoad: 页面加载超时时间
@@ -289,9 +269,7 @@ class DriverPage(BasePage):
         if script is not None:
             self.driver.set_script_timeout(script)
 
-    def wait_ele(self,
-                 loc_or_ele: Union[str, tuple, DriverElement, WebElement],
-                 timeout: float = None) -> 'ElementWaiter':
+    def wait_ele(self, loc_or_ele, timeout=None):
         """等待元素从dom删除、显示、隐藏                             \n
         :param loc_or_ele: 可以是元素、查询字符串、loc元组
         :param timeout: 等待超时时间
@@ -299,13 +277,13 @@ class DriverPage(BasePage):
         """
         return ElementWaiter(self, loc_or_ele, timeout)
 
-    def check_page(self) -> Union[bool, None]:
+    def check_page(self):
         """检查页面是否符合预期            \n
         由子类自行实现各页面的判定规则
         """
         return None
 
-    def run_script(self, script: str, *args) -> Any:
+    def run_script(self, script, *args):
         """执行js代码                 \n
         :param script: js文本
         :param args: 传入的参数
@@ -313,7 +291,7 @@ class DriverPage(BasePage):
         """
         return self.driver.execute_script(script, *args)
 
-    def run_async_script(self, script: str, *args) -> Any:
+    def run_async_script(self, script, *args):
         """以异步方式执行js代码                 \n
         :param script: js文本
         :param args: 传入的参数
@@ -321,7 +299,7 @@ class DriverPage(BasePage):
         """
         return self.driver.execute_async_script(script, *args)
 
-    def run_cdp(self, cmd: str, **cmd_args) -> Any:
+    def run_cdp(self, cmd, **cmd_args):
         """执行Chrome DevTools Protocol语句
         :param cmd: 协议项目
         :param cmd_args: 参数
@@ -329,7 +307,7 @@ class DriverPage(BasePage):
         """
         return self.driver.execute_cdp_cmd(cmd, cmd_args)
 
-    def create_tab(self, url: str = '') -> None:
+    def create_tab(self, url=''):
         """新建并定位到一个标签页,该标签页在最后面       \n
         :param url: 新标签页跳转到的网址
         :return: None
@@ -338,27 +316,27 @@ class DriverPage(BasePage):
         if url:
             self.get(url)
 
-    def close_tabs(self, num_or_handles: Union[int, str, list, tuple] = None) -> None:
+    def close_tabs(self, num_or_handles=None):
         """关闭传入的标签页，默认关闭当前页。可传入多个                                                     \n
         注意：当程序使用的是接管的浏览器，获取到的 handle 顺序和视觉效果不一致，不能按序号关闭。                 \n
         :param num_or_handles:要关闭的标签页序号或handle，可传入handle和序号组成的列表或元组，为None时关闭当前页
         :return: None
         """
-        tabs = (self.current_tab_handle,) if num_or_handles is None else _get_handles(self.tab_handles, num_or_handles)
+        tabs = (self.current_tab_handle,) if num_or_handles is None else get_handles(self.tab_handles, num_or_handles)
         for i in tabs:
             self.driver.switch_to.window(i)
             self.driver.close()
 
         self.to_tab(0)
 
-    def close_other_tabs(self, num_or_handles: Union[int, str, list, tuple] = None) -> None:
+    def close_other_tabs(self, num_or_handles=None):
         """关闭传入的标签页以外标签页，默认保留当前页。可传入多个                                              \n
         注意：当程序使用的是接管的浏览器，获取到的 handle 顺序和视觉效果不一致，不能按序号关闭。                   \n
         :param num_or_handles: 要保留的标签页序号或handle，可传入handle和序号组成的列表或元组，为None时保存当前页
         :return: None
         """
         all_tabs = self.driver.window_handles
-        reserve_tabs = {self.current_tab_handle} if num_or_handles is None else _get_handles(all_tabs, num_or_handles)
+        reserve_tabs = {self.current_tab_handle} if num_or_handles is None else get_handles(all_tabs, num_or_handles)
 
         for i in set(all_tabs) - reserve_tabs:
             self.driver.switch_to.window(i)
@@ -366,7 +344,7 @@ class DriverPage(BasePage):
 
         self.to_tab(0)
 
-    def to_tab(self, num_or_handle: Union[int, str] = 0) -> None:
+    def to_tab(self, num_or_handle=0):
         """跳转到标签页                                                         \n
         注意：当程序使用的是接管的浏览器，获取到的 handle 顺序和视觉效果不一致         \n
         :param num_or_handle: 标签页序号或handle字符串，序号第一个为0，最后为-1
@@ -380,14 +358,14 @@ class DriverPage(BasePage):
         tab = self.driver.window_handles[tab] if isinstance(tab, int) else tab
         self.driver.switch_to.window(tab)
 
-    def set_ua_to_tab(self, ua: str) -> None:
+    def set_ua_to_tab(self, ua):
         """为当前tab设置user agent，只在当前tab有效          \n
         :param ua: user agent字符串
         :return: None
         """
         self.driver.execute_cdp_cmd("Network.setUserAgentOverride", {"userAgent": ua})
 
-    def get_session_storage(self, item: str = None) -> Union[str, dict, None]:
+    def get_session_storage(self, item=None):
         """获取sessionStorage信息，不设置item则获取全部       \n
         :param item: 要获取的项，不设置则返回全部
         :return: sessionStorage一个或所有项内容
@@ -395,7 +373,7 @@ class DriverPage(BasePage):
         js = f'return sessionStorage.getItem("{item}");' if item else 'return sessionStorage;'
         return self.run_script(js)
 
-    def get_local_storage(self, item: str = None) -> Union[str, dict, None]:
+    def get_local_storage(self, item=None):
         """获取localStorage信息，不设置item则获取全部       \n
         :param item: 要获取的项目，不设置则返回全部
         :return: localStorage一个或所有项内容
@@ -403,7 +381,7 @@ class DriverPage(BasePage):
         js = f'return localStorage.getItem("{item}");' if item else 'return localStorage;'
         return self.run_script(js)
 
-    def set_session_storage(self, item: str, value: Union[str, bool]) -> None:
+    def set_session_storage(self, item, value):
         """设置或删除某项sessionStorage信息                         \n
         :param item: 要设置的项
         :param value: 项的值，设置为False时，删除该项
@@ -412,7 +390,7 @@ class DriverPage(BasePage):
         s = f'sessionStorage.removeItem("{item}");' if item is False else f'sessionStorage.setItem("{item}","{value}");'
         self.run_script(s)
 
-    def set_local_storage(self, item: str, value: Union[str, bool]) -> None:
+    def set_local_storage(self, item, value):
         """设置或删除某项localStorage信息                           \n
         :param item: 要设置的项
         :param value: 项的值，设置为False时，删除该项
@@ -421,11 +399,7 @@ class DriverPage(BasePage):
         s = f'localStorage.removeItem("{item}");' if item is False else f'localStorage.setItem("{item}","{value}");'
         self.run_script(s)
 
-    def clean_cache(self,
-                    session_storage: bool = True,
-                    local_storage: bool = True,
-                    cache: bool = True,
-                    cookies: bool = True) -> None:
+    def clean_cache(self, session_storage=True, local_storage=True, cache=True, cookies=True):
         """清除缓存，可选要清除的项                            \n
         :param session_storage: 是否清除sessionStorage
         :param local_storage: 是否清除localStorage
@@ -442,7 +416,7 @@ class DriverPage(BasePage):
         if cookies:
             self.run_cdp('Network.clearBrowserCookies')
 
-    def screenshot(self, path: str = None, filename: str = None, as_bytes: bool = False) -> Union[str, bytes]:
+    def screenshot(self, path=None, filename=None, as_bytes=False):
         """截取页面可见范围截图                                           \n
         :param path: 保存路径
         :param filename: 图片文件名，不传入时以页面title命名
@@ -461,7 +435,7 @@ class DriverPage(BasePage):
         self.driver.save_screenshot(img_path)
         return img_path
 
-    def scroll_to_see(self, loc_or_ele: Union[str, tuple, WebElement, DriverElement]) -> None:
+    def scroll_to_see(self, loc_or_ele):
         """滚动页面直到元素可见                                                        \n
         :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串（详见ele函数注释）
         :return: None
@@ -469,23 +443,23 @@ class DriverPage(BasePage):
         ele = self.ele(loc_or_ele)
         ele.run_script("arguments[0].scrollIntoView();")
 
-    def refresh(self) -> None:
+    def refresh(self):
         """刷新当前页面"""
         self.driver.refresh()
 
-    def stop_loading(self) -> None:
+    def stop_loading(self):
         """强制停止页面加载"""
         self.run_cdp('Page.stopLoading')
 
-    def back(self) -> None:
+    def back(self):
         """在浏览历史中后退一步"""
         self.driver.back()
 
-    def forward(self) -> None:
+    def forward(self):
         """在浏览历史中前进一步"""
         self.driver.forward()
 
-    def set_window_size(self, width: int = None, height: int = None) -> None:
+    def set_window_size(self, width=None, height=None):
         """设置浏览器窗口大小，默认最大化，任一参数为0最小化  \n
         :param width: 浏览器窗口高
         :param height: 浏览器窗口宽
@@ -505,14 +479,14 @@ class DriverPage(BasePage):
             new_y = height or self.driver.get_window_size()['height']
             self.driver.set_window_size(new_x, new_y)
 
-    def chrome_downloading(self, download_path: str) -> list:
+    def chrome_downloading(self, download_path):
         """返回浏览器下载中的文件列表             \n
         :param download_path: 下载文件夹路径
         :return: 文件列表
         """
         return glob(f'{download_path}{sep}*.crdownload')
 
-    def process_alert(self, ok: bool = True, send: str = None, timeout: float = None) -> Union[str, None]:
+    def process_alert(self, ok=True, send=None, timeout=None):
         """处理提示框                                                            \n
         :param ok: True表示确认，False表示取消，其它值不会按按钮但依然返回文本值
         :param send: 处理prompt提示框时可输入文本
@@ -551,10 +525,10 @@ class DriverPage(BasePage):
 class ToFrame(object):
     """用于处理焦点跳转到页面框架的类"""
 
-    def __init__(self, page: DriverPage):
+    def __init__(self, page):
         self.page = page
 
-    def __call__(self, condition: Union[int, str, tuple, WebElement, DriverElement] = 'main'):
+    def __call__(self, condition='main'):
         """跳转到(i)frame，可传入id、name、序号、元素对象、定位符                  \n
         :param condition: (i)frame，可传入id、name、序号、元素对象、定位符
         :return: 当前页面对象
@@ -570,12 +544,12 @@ class ToFrame(object):
 
         return self.page
 
-    def main(self) -> DriverPage:
+    def main(self):
         """焦点跳转到最高层级框架"""
         self.page.driver.switch_to.default_content()
         return self.page
 
-    def parent(self, level: int = 1) -> DriverPage:
+    def parent(self, level=1):
         """焦点跳转到上级框架，可指定上级层数       \n
         :param level: 上面第几层框架
         :return: 框架所在页面对象
@@ -586,7 +560,7 @@ class ToFrame(object):
             self.page.driver.switch_to.parent_frame()
         return self.page
 
-    def by_id(self, id_: str) -> DriverPage:
+    def by_id(self, id_):
         """焦点跳转到id为该值的(i)frame              \n
         :param id_: (i)frame的id属性值
         :return: 框架所在页面对象
@@ -594,7 +568,7 @@ class ToFrame(object):
         self.page.driver.switch_to.frame(id_)
         return self.page
 
-    def by_name(self, name: str) -> DriverPage:
+    def by_name(self, name):
         """焦点跳转到name为该值的(i)frame              \n
         :param name: (i)frame的name属性值
         :return: 框架所在页面对象
@@ -602,7 +576,7 @@ class ToFrame(object):
         self.page.driver.switch_to.frame(name)
         return self.page
 
-    def by_index(self, index: int) -> DriverPage:
+    def by_index(self, index):
         """焦点跳转到页面中第几个(i)frame              \n
         :param index: 页面中第几个(i)frame
         :return: 框架所在页面对象
@@ -610,7 +584,7 @@ class ToFrame(object):
         self.page.driver.switch_to.frame(index)
         return self.page
 
-    def by_loc(self, loc: Union[str, tuple]) -> DriverPage:
+    def by_loc(self, loc):
         """焦点跳转到根据定位符获取到的(i)frame                   \n
         :param loc: 定位符，支持selenium原生和DriverPage定位符
         :return: 框架所在页面对象
@@ -618,7 +592,7 @@ class ToFrame(object):
         self.page.driver.switch_to.frame(self.page(loc).inner_ele)
         return self.page
 
-    def by_ele(self, ele: Union[DriverElement, WebElement]) -> DriverPage:
+    def by_ele(self, ele):
         """焦点跳转到传入的(i)frame元素对象              \n
         :param ele: (i)frame元素对象
         :return: 框架所在页面对象
@@ -629,7 +603,7 @@ class ToFrame(object):
         return self.page
 
 
-def _get_handles(handles: list, num_or_handles: Union[int, str, list, tuple]) -> set:
+def get_handles(handles, num_or_handles):
     """返回指定标签页组成的set
     :param handles: handles列表
     :param num_or_handles: 指定的标签页，可以是多个
