@@ -294,7 +294,7 @@ def _get_chrome_path(ini_path: str = None,
 
     # -----------从系统变量中获取--------------
     if from_system_path:
-        paths = popen('set path').read().lower()
+        paths = popen('set path').read().encode('gbk').decode('utf-8').lower()
         r = search(r'[^;]*chrome[^;]*', paths)
 
         if r:
