@@ -73,6 +73,15 @@ class SessionPage(BasePage):
 
             self.session.cookies.set(cookie['name'], cookie['value'], **kwargs)
 
+    def set_headers(self, headers):
+        """设置通用的headers，设置的headers值回逐个覆盖原有的，不会清理原来的        \n
+        :param headers: dict形式的headers
+        :return: None
+        """
+        headers = CaseInsensitiveDict(headers)
+        for i in headers:
+            self.session.headers[i] = headers[i]
+
     def __call__(self, loc_or_str, timeout=None):
         """在内部查找元素                                                  \n
         例：ele2 = ele1('@id=ele_id')                                     \n
@@ -95,8 +104,11 @@ class SessionPage(BasePage):
 
     @property
     def json(self):
-        """当返回内容是json格式时，返回对应的字典"""
-        return self.response.json()
+        """当返回内容是json格式时，返回对应的字典，非json格式时返回None"""
+        try:
+            return self.response.json()
+        except Exception:
+            return None
 
     def get(self, url, show_errmsg=False, retry=None, interval=None, timeout=None, **kwargs):
         """用get方式跳转到url                                 \n
