@@ -13,17 +13,17 @@ from .chromium_base import ChromiumBase, Timeout
 from .chromium_page import ChromiumPage
 from .config import DriverOptions, SessionOptions, cookies_to_tuple
 from .session_page import SessionPage
-from .tab import Tab
+from .chromium_driver import ChromiumDriver
 
 
 class WebPage(SessionPage, ChromiumPage, BasePage):
     """整合浏览器和request的页面类"""
 
     def __init__(self, mode='d', timeout=10, tab_id=None, driver_or_options=None, session_or_options=None):
-        """初始化函数                                                                        \n
+        """初始化函数                                                                              \n
         :param mode: 'd' 或 's'，即driver模式和session模式
         :param timeout: 超时时间，d模式时为寻找元素时间，s模式时为连接时间，默认10秒
-        :param driver_or_options: Tab对象或DriverOptions对象，只使用s模式时应传入False
+        :param driver_or_options: ChromiumDriver对象或DriverOptions对象，只使用s模式时应传入False
         :param session_or_options: Session对象或SessionOptions对象，只使用d模式时应传入False
         """
         self._mode = mode.lower()
@@ -111,19 +111,19 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
 
     @property
     def driver(self):
-        """返回纯粹的Tab对象"""
+        """返回纯粹的ChromiumDriver对象"""
         return self._tab_obj
 
     @property
     def _wait_driver(self):
-        """返回用于控制浏览器的Tab对象，会先等待页面加载完毕"""
+        """返回用于控制浏览器的ChromiumDriver对象，会先等待页面加载完毕"""
         while self._is_loading:
             sleep(.1)
         return self._driver
 
     @property
     def _driver(self):
-        """返回纯粹的Tab对象，调用时切换到d模式，并连接浏览器"""
+        """返回纯粹的ChromiumDriver对象，调用时切换到d模式，并连接浏览器"""
         self.change_mode('d')
         if self._tab_obj is None:
             self._connect_browser(self._driver_options, self._setting_tab_id)
@@ -198,10 +198,9 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             return super(SessionPage, self).s_eles(loc_or_str)
 
     def change_mode(self, mode=None, go=True, copy_cookies=True):
-        """切换模式，接收's'或'd'，除此以外的字符串会切换为 d 模式     \n
-        切换时会把当前模式的cookies复制到目标模式                   \n
-        切换后，如果go是True，调用相应的get函数使访问的页面同步        \n
-        注意：s转d时，若浏览器当前网址域名和s模式不一样，必须会跳转      \n
+        """切换模式，接收's'或'd'，除此以外的字符串会切换为 d 模式                         \n
+        如copy_cookies为True，切换时会把当前模式的cookies复制到目标模式                   \n
+        切换后，如果go是True，调用相应的get函数使访问的页面同步                            \n
         :param mode: 模式字符串
         :param go: 是否跳转到原模式的url
         :param copy_cookies: 是否复制cookies到目标模式
@@ -283,6 +282,12 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             return cookies
 
     def set_cookies(self, cookies, set_session=False, set_driver=False):
+        """添加cookies信息到浏览器或session对象                                                 \n
+        :param cookies: 可以接收`CookieJar`、`list`、`tuple`、`str`、`dict`格式的`cookies`
+        :param set_session: 是否设置到Session对象
+        :param set_driver: 是否设置到浏览器
+        :return: None
+        """
         # 添加cookie到driver
         if set_driver:
             cookies = cookies_to_tuple(cookies)
@@ -300,15 +305,15 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
         if set_session:
             super().set_cookies(cookies)
 
-    # def set_headers(self, headers: dict) -> None:
-    #     """设置固定发送的headers                        \n
-    #     :param headers: dict格式的headers数据
-    #     :return: None
-    #     """
-    #     if self._mode == 's':
-    #         self.session.headers = headers
-    #     elif self._mode == 'd':
-    #         super(SessionPage, self).set_headers(headers)
+    def set_headers(self, headers: dict) -> None:
+        """设置固定发送的headers                        \n
+        :param headers: dict格式的headers数据
+        :return: None
+        """
+        if self._has_session:
+            return super().set_headers(headers)
+        if self._has_driver:
+            super(SessionPage, self).set_headers(headers)
 
     def check_page(self, by_requests=False):
         """d模式时检查网页是否符合预期                \n
@@ -377,20 +382,20 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
         elif self._mode == 'd':
             return super(SessionPage, self)._ele(loc_or_ele, timeout=timeout, single=single, relative=relative)
 
-    def _set_driver_options(self, Tab_or_Options):
+    def _set_driver_options(self, driver_or_Options):
         """处理driver设置"""
-        if Tab_or_Options is None:
+        if driver_or_Options is None:
             self._driver_options = DriverOptions()
 
-        elif Tab_or_Options is False:
+        elif driver_or_Options is False:
             self._driver_options = DriverOptions(read_file=False)
 
-        elif isinstance(Tab_or_Options, Tab):
-            self._connect_browser(Tab_or_Options)
+        elif isinstance(driver_or_Options, ChromiumDriver):
+            self._connect_browser(driver_or_Options)
             self._has_driver = True
 
-        elif isinstance(Tab_or_Options, DriverOptions):
-            self._driver_options = Tab_or_Options
+        elif isinstance(driver_or_Options, DriverOptions):
+            self._driver_options = driver_or_Options
 
         else:
             raise TypeError('driver_or_options参数只能接收WebDriver, Options, DriverOptions或False。')
